@@ -46,8 +46,7 @@ function(expression = "", data = NULL, separate = FALSE) {
                 data[[i]] <- eval.parent(parse(text = sprintf("get(\"%s\")", colnms[i]), n = 1))
             }
             if (length(unique(unlist(lapply(data, length)))) > 1) {
-                cat("\n")
-                stop(simpleError("Objects should be vectors of the same length.\n\n"))
+                stopError("Objects should be vectors of the same length.")
             }
             names(data) <- colnms
             data <- as.data.frame(data)
@@ -76,8 +75,7 @@ function(expression = "", data = NULL, separate = FALSE) {
             nao <- na.omit(temp[, j])
             if (any(abs(nao - round(nao)) >= .Machine$double.eps^0.5)) { 
                 if (length(val[[j]]) > 1) {
-                    cat("\n")
-                    stop(simpleError("Multiple values specified for fuzzy data.\n\n"))
+                    stopError("Multiple values specified for fuzzy data.")
                 }
                 if (val[[j]] == 0) {
                     temp[, j] <- 1 - temp[, j]
